@@ -128,9 +128,9 @@ def create_and_add_to_pretty_table(table_fields, returned_alerts):
             elif field == 'integration':
                 item_to_add.append(item['integration']['name'])
             elif field == 'tags':
-                if item['tags']: item_to_add.append(' '.join(sorted(item['tags'])))
+                item_to_add.append(' '.join(sorted(item['tags'])))
             elif field in format_table.field_names:
-                if item[field]: item_to_add.append(item[field])
+                item_to_add.append(item[field])
         format_table.add_row(item_to_add)
     return format_table
 
